.. _team:

=====
Roles
=====

The roles are described in scikit-time's :ref:`governance` document.
A list of all contributors can be found `here <contributors.md>`_.

Community Council
-----------------
.. list-table::
   :header-rows: 1

   * - Name
     - GitHub ID
   * - tbd
     - :user:`tbd`

Code of Conduct Committee
-------------------------

.. list-table::
   :header-rows: 1

   * - Name
     - GitHub ID
   * - Guzal Bulatova
     - :user:`GuzalBulatova`
   * - Katie Buchhorn
     - :user:`KatieBuc`
   * - Matthew Middlehurst
     - :user:`mattewmiddlehurst`
   * - Patrick Schäfer
     - :user:`patrickzib`

Core Developers
---------------

.. list-table::
   :header-rows: 1

   * - Name
     - GitHub ID
   * - Anthony Bagnall
     - :user:`TonyBagnall`
   * - Chris Holder
     - :user:`chrisholder`
   * - Guzal Bulatova
     - :user:`GuzalBulatova`
   * - Leonidas Tsaprounis
     - :user:`ltsaprounis`
   * - Łukasz Mentel
     - :user:`lmmentel`
   * - Martin Walter
     - :user:`aiwalter`
   * - Matthew Middlehurst
     - :user:`mattewmiddlehurst`
   * - Patrick Schäfer
     - :user:`patrickzib`

Pre-fork Core Developers
------------------------

.. list-table::
   :header-rows: 1

   * - Name
     - GitHub ID
   * - Aaron Bostrom
     - :user:`abostrom`
   * - Ayushmaan Seth
     - :user:`ayushmaanseth`
   * - George Oastler
     - :user:`goastler`
   * - Hongyi Yang
     - :user:`hyang1996`
   * - James Large
     - :user:`james-large`
   * - Jason Lines
     - :user:`jasonlines`
   * - Mathew Smith
     - :user:`matteogales`
   * - Patrick Rockenschaub
     - :user:`prockenschaub`
   * - Sajaysurya Ganesh
     - :user:`sajaysurya`
   * - Franz Király
     - :user:`fkiraly`
   * - Markus Löning
     - :user:`mloning`
   * - Mirae Parker
     - :user:`miraep8`
   * - Ryan Kuhns
     - :user:`rnkuhns`
   * - Sagar Mishra
     - :user:`achieveordie`
   * - Stanislav Khrapov
     - :user:`khrapovs`
   * - Svea Marie Meyer
     - :user:`SveaMeyer13`
   * - Lovkush Agarwal
     - :user:`lovkush-a`
   * - Freddy A Boulton
     - :user:`freddyaboulton`
   * - Daniel Bartling
     - :user:`danbartl`
   * - Anonymous upon contributor's request
     - :user:`big-o`
